@@ -1,3 +1,4 @@
+"""CLI for ``tmuxp debug-info`` subcommand."""
 import argparse
 import os
 import pathlib
@@ -7,7 +8,6 @@ import sys
 import typing as t
 
 from colorama import Fore
-
 from libtmux.__about__ import __version__ as libtmux_version
 from libtmux.common import get_version, tmux_cmd
 
@@ -20,39 +20,32 @@ tmuxp_path = pathlib.Path(__file__).parent.parent
 def create_debug_info_subparser(
     parser: argparse.ArgumentParser,
 ) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``debug-info`` subcommand."""
     return parser
 
 
 def command_debug_info(
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
-    """
-    Print debug info to submit with Issues.
-    """
+    """Entrypoint for ``tmuxp debug-info`` to print debug info to submit with issues."""
 
-    def prepend_tab(strings):
-        """
-        Prepend tab to strings in list.
-        """
-        return list(map(lambda x: "\t%s" % x, strings))
+    def prepend_tab(strings: t.List[str]) -> t.List[str]:
+        """Prepend tab to strings in list."""
+        return ["\t%s" % x for x in strings]
 
-    def output_break():
-        """
-        Generate output break.
-        """
+    def output_break() -> str:
+        """Generate output break."""
         return "-" * 25
 
-    def format_tmux_resp(std_resp):
-        """
-        Format tmux command response for tmuxp stdout.
-        """
+    def format_tmux_resp(std_resp: tmux_cmd) -> str:
+        """Format tmux command response for tmuxp stdout."""
         return "\n".join(
             [
                 "\n".join(prepend_tab(std_resp.stdout)),
                 Fore.RED,
                 "\n".join(prepend_tab(std_resp.stderr)),
                 Fore.RESET,
-            ]
+            ],
         )
 
     output = [
@@ -65,8 +58,8 @@ def command_debug_info(
                     "arch: %s" % platform.machine(),
                     "uname: %s" % "; ".join(platform.uname()[:3]),
                     "version: %s" % platform.version(),
-                ]
-            )
+                ],
+            ),
         ),
         output_break(),
         "python version: %s" % " ".join(sys.version.split("\n")),
