@@ -1,3 +1,4 @@
+"""CLI for ``tmuxp edit`` subcommand."""
 import argparse
 import os
 import pathlib
@@ -10,6 +11,7 @@ from tmuxp.workspace.finders import find_workspace_file
 def create_edit_subparser(
     parser: argparse.ArgumentParser,
 ) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``edit`` subcommand."""
     parser.add_argument(
         dest="workspace_file",
         metavar="workspace-file",
@@ -22,7 +24,8 @@ def create_edit_subparser(
 def command_edit(
     workspace_file: t.Union[str, pathlib.Path],
     parser: t.Optional[argparse.ArgumentParser] = None,
-):
+) -> None:
+    """Entrypoint for ``tmuxp edit``, open tmuxp workspace file in system editor."""
     workspace_file = find_workspace_file(workspace_file)
 
     sys_editor = os.environ.get("EDITOR", "vim")
