@@ -1,3 +1,4 @@
+"""CLI for ``tmuxp freeze`` subcommand."""
 import argparse
 import os
 import pathlib
@@ -5,21 +6,24 @@ import sys
 import typing as t
 
 from libtmux.server import Server
-from tmuxp.config_reader import ConfigReader
+
+from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.exc import TmuxpException
 from tmuxp.workspace.finders import get_workspace_dir
 
-from .. import util
+from .. import exc, util
 from ..workspace import freezer
 from .utils import prompt, prompt_choices, prompt_yes_no
 
 if t.TYPE_CHECKING:
-    from typing_extensions import Literal, TypeAlias, TypeGuard
+    from typing_extensions import TypeAlias, TypeGuard
 
-    CLIOutputFormatLiteral: TypeAlias = Literal["yaml", "json"]
+    CLIOutputFormatLiteral: TypeAlias = t.Literal["yaml", "json"]
 
 
 class CLIFreezeNamespace(argparse.Namespace):
+    """Typed :class:`argparse.Namespace` for tmuxp freeze command."""
+
     session_name: str
     socket_name: t.Optional[str]
     socket_path: t.Optional[str]
@@ -30,15 +34,10 @@ class CLIFreezeNamespace(argparse.Namespace):
     force: t.Optional[bool]
 
 
-def session_completion(ctx, params, incomplete):
-    server = Server()
-    choices = [session.name for session in server.sessions]
-    return sorted(str(c) for c in choices if str(c).startswith(incomplete))
-
-
 def create_freeze_subparser(
     parser: argparse.ArgumentParser,
 ) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``freeze`` subcommand."""
     parser.add_argument(
         dest="session_name",
         metavar="session-name",
@@ -46,10 +45,16 @@ def create_freeze_subparser(
         action="store",
     )
     parser.add_argument(
-        "-S", dest="socket_path", metavar="socket-path", help="pass-through for tmux -S"
+        "-S",
+        dest="socket_path",
+        metavar="socket-path",
+        help="pass-through for tmux -S",
     )
     parser.add_argument(
-        "-L", dest="socket_name", metavar="socket-name", help="pass-through for tmux -L"
+        "-L",
+        dest="socket_name",
+        metavar="socket-name",
+        help="pass-through for tmux -L",
     )
     parser.add_argument(
         "-f",
@@ -92,10 +97,11 @@ def command_freeze(
     args: CLIFreezeNamespace,
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
-    """Snapshot a tmux session into a tmuxp workspace.
+    """Entrypoint for ``tmuxp freeze``, snapshot a tmux session into a tmuxp workspace.
 
-    If SESSION_NAME is provided, snapshot that session. Otherwise, use the
-    current session."""
+    If SESSION_NAME is provided, snapshot that session. Otherwise, use the current
+    session.
+    """
     server = Server(socket_name=args.socket_name, socket_path=args.socket_path)
 
     try:
@@ -105,7 +111,7 @@ def command_freeze(
             session = util.get_session(server)
 
         if not session:
-            raise TmuxpException("Session not found.")
+            raise exc.SessionNotFound()
     except TmuxpException as e:
         print(e)
         return
@@ -118,19 +124,19 @@ def command_freeze(
         print(
             "---------------------------------------------------------------"
             "\n"
-            "Freeze does its best to snapshot live tmux sessions.\n"
+            "Freeze does its best to snapshot live tmux sessions.\n",
         )
     if not (
         args.answer_yes
         or prompt_yes_no(
-            "The new workspace will require adjusting afterwards. Save workspace file?"
+            "The new workspace will require adjusting afterwards. Save workspace file?",
         )
     ):
         if not args.quiet:
             print(
                 "tmuxp has examples in JSON and YAML format at "
                 "<http://tmuxp.git-pull.com/examples.html>\n"
-                "View tmuxp docs at <http://tmuxp.git-pull.com/>."
+                "View tmuxp docs at <http://tmuxp.git-pull.com/>.",
             )
         sys.exit()
 
@@ -143,7 +149,7 @@ def command_freeze(
                     frozen_workspace.get("session_name"),
                     args.workspace_format or "yaml",
                 ),
-            )
+            ),
         )
         dest_prompt = prompt(
             "Save to: %s" % save_to,
@@ -176,27 +182,31 @@ def command_freeze(
 
         workspace_format = extract_workspace_format(dest)
         if not is_valid_ext(workspace_format):
-            workspace_format = prompt_choices(
+            _workspace_format = prompt_choices(
                 "Couldn't ascertain one of [%s] from file name. Convert to"
                 % ", ".join(valid_workspace_formats),
-                choices=valid_workspace_formats,
+                choices=t.cast(t.List[str], valid_workspace_formats),
                 default="yaml",
             )
+            assert is_valid_ext(_workspace_format)
+            workspace_format = _workspace_format
 
     if workspace_format == "yaml":
         workspace = configparser.dump(
-            format="yaml", indent=2, default_flow_style=False, safe=True
+            fmt="yaml",
+            indent=2,
+            default_flow_style=False,
+            safe=True,
         )
     elif workspace_format == "json":
-        workspace = configparser.dump(format="json", indent=2)
+        workspace = configparser.dump(fmt="json", indent=2)
 
     if args.answer_yes or prompt_yes_no("Save to %s?" % dest):
         destdir = os.path.dirname(dest)
         if not os.path.isdir(destdir):
             os.makedirs(destdir)
-        buf = open(dest, "w")
-        buf.write(workspace)
-        buf.close()
+        with open(dest, "w") as buf:
+            buf.write(workspace)
 
         if not args.quiet:
             print("Saved to %s." % dest)
