@@ -1,51 +1,50 @@
+"""CLI for ``tmuxp shell`` subcommand."""
 import argparse
 import os
 import pathlib
 import sys
 import typing as t
 
-from tmuxp.config_reader import ConfigReader
+from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.workspace.finders import find_workspace_file
 
 from ..workspace import importers
 from .utils import prompt, prompt_choices, prompt_yes_no, tmuxp_echo
 
 
-def get_tmuxinator_dir() -> str:
-    """
-    Return tmuxinator configuration directory.
+def get_tmuxinator_dir() -> pathlib.Path:
+    """Return tmuxinator configuration directory.
 
     Checks for ``TMUXINATOR_CONFIG`` environmental variable.
 
     Returns
     -------
-    str :
+    pathlib.Path :
         absolute path to tmuxinator config directory
 
     See Also
     --------
-    :meth:`tmuxp.workspace.importers.tmuxinator.import_tmuxinator`
+    :meth:`tmuxp.workspace.importers.import_tmuxinator`
     """
     if "TMUXINATOR_CONFIG" in os.environ:
-        return os.path.expanduser(os.environ["TMUXINATOR_CONFIG"])
+        return pathlib.Path(os.environ["TMUXINATOR_CONFIG"]).expanduser()
 
-    return os.path.expanduser("~/.tmuxinator/")
+    return pathlib.Path("~/.tmuxinator/").expanduser()
 
 
-def get_teamocil_dir() -> str:
-    """
-    Return teamocil configuration directory.
+def get_teamocil_dir() -> pathlib.Path:
+    """Return teamocil configuration directory.
 
     Returns
     -------
-    str :
+    pathlib.Path :
         absolute path to teamocil config directory
 
     See Also
     --------
-    :meth:`tmuxp.workspace.importers.teamocil.import_teamocil`
+    :meth:`tmuxp.workspace.importers.import_teamocil`
     """
-    return os.path.expanduser("~/.teamocil/")
+    return pathlib.Path("~/.teamocil/").expanduser()
 
 
 def _resolve_path_no_overwrite(workspace_file: str) -> str:
@@ -59,19 +58,23 @@ def command_import(
     workspace_file: str,
     print_list: str,
     parser: argparse.ArgumentParser,
-):
+) -> None:
     """Import a teamocil/tmuxinator config."""
 
 
 def create_import_subparser(
     parser: argparse.ArgumentParser,
 ) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``import`` subparser."""
     importsubparser = parser.add_subparsers(
-        title="commands", description="valid commands", help="additional help"
+        title="commands",
+        description="valid commands",
+        help="additional help",
     )
 
     import_teamocil = importsubparser.add_parser(
-        "teamocil", help="convert and import a teamocil config"
+        "teamocil",
+        help="convert and import a teamocil config",
     )
 
     import_teamocilgroup = import_teamocil.add_mutually_exclusive_group(required=True)
@@ -83,15 +86,17 @@ def create_import_subparser(
         help="checks current ~/.teamocil and current directory for yaml files",
     )
     import_teamocil.set_defaults(
-        callback=command_import_teamocil, import_subparser_name="teamocil"
+        callback=command_import_teamocil,
+        import_subparser_name="teamocil",
     )
 
     import_tmuxinator = importsubparser.add_parser(
-        "tmuxinator", help="convert and import a tmuxinator config"
+        "tmuxinator",
+        help="convert and import a tmuxinator config",
     )
 
     import_tmuxinatorgroup = import_tmuxinator.add_mutually_exclusive_group(
-        required=True
+        required=True,
     )
     tmuxinator_workspace_file = import_tmuxinatorgroup.add_argument(
         dest="workspace_file",
@@ -102,7 +107,8 @@ def create_import_subparser(
     )
 
     import_tmuxinator.set_defaults(
-        callback=command_import_tmuxinator, import_subparser_name="tmuxinator"
+        callback=command_import_tmuxinator,
+        import_subparser_name="tmuxinator",
     )
 
     try:
@@ -116,16 +122,27 @@ def create_import_subparser(
     return parser
 
 
+class ImportConfigFn(t.Protocol):
+    """Typing for import configuration callback function."""
+
+    def __call__(self, workspace_dict: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
+        """Execute tmuxp import function."""
+        ...
+
+
 def import_config(
     workspace_file: str,
-    importfunc: t.Callable,
+    importfunc: ImportConfigFn,
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
+    """Import a configuration from a workspace_file."""
     existing_workspace_file = ConfigReader._from_file(pathlib.Path(workspace_file))
     cfg_reader = ConfigReader(importfunc(existing_workspace_file))
 
     workspace_file_format = prompt_choices(
-        "Convert to", choices=["yaml", "json"], default="yaml"
+        "Convert to",
+        choices=["yaml", "json"],
+        default="yaml",
     )
 
     if workspace_file_format == "yaml":
@@ -138,31 +155,31 @@ def import_config(
     tmuxp_echo(
         new_config + "---------------------------------------------------------------"
         "\n"
-        "Configuration import does its best to convert files.\n"
+        "Configuration import does its best to convert files.\n",
     )
     if prompt_yes_no(
-        "The new config *WILL* require adjusting afterwards. Save config?"
+        "The new config *WILL* require adjusting afterwards. Save config?",
     ):
         dest = None
         while not dest:
             dest_path = prompt(
-                "Save to [%s]" % os.getcwd(), value_proc=_resolve_path_no_overwrite
+                "Save to [%s]" % os.getcwd(),
+                value_proc=_resolve_path_no_overwrite,
             )
 
             # dest = dest_prompt
             if prompt_yes_no("Save to %s?" % dest_path):
                 dest = dest_path
 
-        buf = open(dest, "w")
-        buf.write(new_config)
-        buf.close()
+        with open(dest, "w") as buf:
+            buf.write(new_config)
 
         tmuxp_echo("Saved to %s." % dest)
     else:
         tmuxp_echo(
             "tmuxp has examples in JSON and YAML format at "
             "<http://tmuxp.git-pull.com/examples.html>\n"
-            "View tmuxp docs at <http://tmuxp.git-pull.com/>"
+            "View tmuxp docs at <http://tmuxp.git-pull.com/>",
         )
         sys.exit()
 
@@ -171,10 +188,14 @@ def command_import_tmuxinator(
     workspace_file: str,
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
-    """Convert a tmuxinator config from workspace_file to tmuxp format and import
-    it into tmuxp."""
+    """Entrypoint for ``tmuxp import tmuxinator`` subcommand.
+
+    Converts a tmuxinator config from workspace_file to tmuxp format and import
+    it into tmuxp.
+    """
     workspace_file = find_workspace_file(
-        workspace_file, workspace_dir=get_tmuxinator_dir()
+        workspace_file,
+        workspace_dir=get_tmuxinator_dir(),
     )
     import_config(workspace_file, importers.import_tmuxinator)
 
@@ -183,10 +204,14 @@ def command_import_teamocil(
     workspace_file: str,
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
-    """Convert a teamocil config from workspace_file to tmuxp format and import
-    it into tmuxp."""
+    """Entrypoint for ``tmuxp import teamocil`` subcommand.
+
+    Convert a teamocil config from workspace_file to tmuxp format and import
+    it into tmuxp.
+    """
     workspace_file = find_workspace_file(
-        workspace_file, workspace_dir=get_teamocil_dir()
+        workspace_file,
+        workspace_dir=get_teamocil_dir(),
     )
 
     import_config(workspace_file, importers.import_teamocil)
