@@ -1,9 +1,4 @@
-"""Command line tool for managing tmuxp workspaces.
-
-tmuxp.cli.load
-~~~~~~~~~~~~~~
-
-"""
+"""CLI for ``tmuxp load`` subcommand."""
 import argparse
 import importlib
 import logging
@@ -16,25 +11,31 @@ import typing as t
 from libtmux.common import has_gte_version
 from libtmux.server import Server
 from libtmux.session import Session
+
 from tmuxp.types import StrPath
 
-from .. import config_reader, exc, log, util
+from .. import exc, log, util
+from .._internal import config_reader
 from ..workspace import loader
 from ..workspace.builder import WorkspaceBuilder
-from ..workspace.finders import find_workspace_file, get_workspace_dir, in_dir
+from ..workspace.finders import find_workspace_file, get_workspace_dir
 from .utils import prompt_choices, prompt_yes_no, style, tmuxp_echo
 
 if t.TYPE_CHECKING:
-    from typing_extensions import Literal, NotRequired, TypeAlias, TypedDict
+    from typing_extensions import NotRequired, TypeAlias, TypedDict
 
-    CLIColorsLiteral: TypeAlias = Literal[56, 88]
+    CLIColorsLiteral: TypeAlias = t.Literal[56, 88]
 
     class OptionOverrides(TypedDict):
+        """Optional argument overrides for tmuxp load."""
+
         detached: NotRequired[bool]
         new_session_name: NotRequired[t.Optional[str]]
 
 
 class CLILoadNamespace(argparse.Namespace):
+    """Typed :class:`argparse.Namespace` for tmuxp load command."""
+
     workspace_files: t.List[str]
     socket_name: t.Optional[str]
     socket_path: t.Optional[str]
@@ -49,8 +50,8 @@ class CLILoadNamespace(argparse.Namespace):
 def set_layout_hook(session: Session, hook_name: str) -> None:
     """Set layout hooks to normalize layout.
 
-    References:
-
+    References
+    ----------
         - tmuxp issue: https://github.com/tmux-python/tmuxp/issues/309
         - tmux issue: https://github.com/tmux/tmux/issues/1106
 
@@ -90,11 +91,7 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
         hook_cmd.append("selectw -p")
 
     # unset the hook immediately after executing
-    hook_cmd.append(
-        "set-hook -u -t {target_session} {hook_name}".format(
-            target_session=session.id, hook_name=hook_name
-        )
-    )
+    hook_cmd.append(f"set-hook -u -t {session.id} {hook_name}")
     hook_cmd.append(f"selectw -t {attached_window.id}")
 
     # join the hook's commands with semicolons
@@ -107,44 +104,56 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
     session.cmd(*cmd)
 
 
-def load_plugins(sconf: t.Any) -> t.List[t.Any]:
-    """
-    Load and return plugins in workspace
-    """
+def load_plugins(session_config: t.Dict[str, t.Any]) -> t.List[t.Any]:
+    """Load and return plugins in workspace."""
     plugins = []
-    if "plugins" in sconf:
-        for plugin in sconf["plugins"]:
+    if "plugins" in session_config:
+        for plugin in session_config["plugins"]:
             try:
                 module_name = plugin.split(".")
                 module_name = ".".join(module_name[:-1])
                 plugin_name = plugin.split(".")[-1]
+            except Exception as error:
+                tmuxp_echo(
+                    style("[Plugin Error] ", fg="red")
+                    + f"Couldn't load {plugin}\n"
+                    + style(f"{error}", fg="yellow"),
+                )
+                sys.exit(1)
+
+            try:
                 plugin = getattr(importlib.import_module(module_name), plugin_name)
                 plugins.append(plugin())
             except exc.TmuxpPluginException as error:
                 if not prompt_yes_no(
-                    "%sSkip loading %s?"
-                    % (style(str(error), fg="yellow"), plugin_name),
+                    "{}Skip loading {}?".format(
+                        style(
+                            str(error),
+                            fg="yellow",
+                        ),
+                        plugin_name,
+                    ),
                     default=True,
                 ):
                     tmuxp_echo(
                         style("[Not Skipping] ", fg="yellow")
-                        + "Plugin versions constraint not met. Exiting..."
+                        + "Plugin versions constraint not met. Exiting...",
                     )
                     sys.exit(1)
             except Exception as error:
                 tmuxp_echo(
                     style("[Plugin Error] ", fg="red")
                     + f"Couldn't load {plugin}\n"
-                    + style(f"{error}", fg="yellow")
+                    + style(f"{error}", fg="yellow"),
                 )
                 sys.exit(1)
 
     return plugins
 
 
-def _reattach(builder: WorkspaceBuilder):
+def _reattach(builder: WorkspaceBuilder) -> None:
     """
-    Reattach session (depending on env being inside tmux already or not)
+    Reattach session (depending on env being inside tmux already or not).
 
     Parameters
     ----------
@@ -158,6 +167,7 @@ def _reattach(builder: WorkspaceBuilder):
 
     If not, ``tmux attach-session`` loads the client to the target session.
     """
+    assert builder.session is not None
     for plugin in builder.plugins:
         plugin.reattach(builder.session)
         proc = builder.session.cmd("display-message", "-p", "'#S'")
@@ -173,7 +183,7 @@ def _reattach(builder: WorkspaceBuilder):
 
 def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
     """
-    Load workspace in new session
+    Load workspace in new session.
 
     Parameters
     ----------
@@ -181,6 +191,7 @@ def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
     detached : bool
     """
     builder.build()
+    assert builder.session is not None
 
     if "TMUX" in os.environ:  # tmuxp ran from inside tmux
         # unset TMUX, save it, e.g. '/tmp/tmux-1000/default,30668,0'
@@ -206,7 +217,7 @@ def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
 
 def _load_detached(builder: WorkspaceBuilder) -> None:
     """
-    Load workspace in new session but don't attach
+    Load workspace in new session but don't attach.
 
     Parameters
     ----------
@@ -214,6 +225,8 @@ def _load_detached(builder: WorkspaceBuilder) -> None:
     """
     builder.build()
 
+    assert builder.session is not None
+
     if has_gte_version("2.6"):  # prepare for both cases
         set_layout_hook(builder.session, "client-attached")
         set_layout_hook(builder.session, "client-session-changed")
@@ -223,7 +236,7 @@ def _load_detached(builder: WorkspaceBuilder) -> None:
 
 def _load_append_windows_to_current_session(builder: WorkspaceBuilder) -> None:
     """
-    Load workspace as new windows in current session
+    Load workspace as new windows in current session.
 
     Parameters
     ----------
@@ -231,19 +244,20 @@ def _load_append_windows_to_current_session(builder: WorkspaceBuilder) -> None:
     """
     current_attached_session = builder.find_current_attached_session()
     builder.build(current_attached_session, append=True)
+    assert builder.session is not None
     if has_gte_version("2.6"):  # prepare for both cases
         set_layout_hook(builder.session, "client-attached")
         set_layout_hook(builder.session, "client-session-changed")
 
 
 def _setup_plugins(builder: WorkspaceBuilder) -> Session:
-    """
-    Runs after before_script
+    """Execute hooks for plugins running after ``before_script``.
 
     Parameters
     ----------
     builder: :class:`workspace.builder.WorkspaceBuilder`
     """
+    assert builder.session is not None
     for plugin in builder.plugins:
         plugin.before_script(builder.session)
 
@@ -261,8 +275,7 @@ def load_workspace(
     answer_yes: bool = False,
     append: bool = False,
 ) -> t.Optional[Session]:
-    """
-    Load a tmux "workspace" session via tmuxp file.
+    """Entrypoint for ``tmuxp load``, load a tmuxp "workspace" session via config file.
 
     Parameters
     ----------
@@ -288,7 +301,6 @@ def load_workspace(
 
     Notes
     -----
-
     tmuxp will check and load a workspace file. The file will use ConfigReader
     to load a JSON/YAML into a :py:obj:`dict`. Then :func:`loader.expand` and
     :func:`loader.trickle` will be used to expand any shorthands, template
@@ -361,7 +373,7 @@ def load_workspace(
 
     tmuxp_echo(
         style("[Loading] ", fg="green")
-        + style(str(workspace_file), fg="blue", bold=True)
+        + style(str(workspace_file), fg="blue", bold=True),
     )
 
     # ConfigReader allows us to open a yaml or json file as a dict
@@ -369,7 +381,8 @@ def load_workspace(
 
     # shapes workspaces relative to config / profile file location
     expanded_workspace = loader.expand(
-        raw_workspace, cwd=os.path.dirname(workspace_file)
+        raw_workspace,
+        cwd=os.path.dirname(workspace_file),
     )
 
     # Overridden session name
@@ -390,7 +403,9 @@ def load_workspace(
 
     try:  # load WorkspaceBuilder object for tmuxp workspace / tmux server
         builder = WorkspaceBuilder(
-            sconf=expanded_workspace, plugins=load_plugins(expanded_workspace), server=t
+            session_config=expanded_workspace,
+            plugins=load_plugins(expanded_workspace),
+            server=t,
         )
     except exc.EmptyWorkspaceException:
         tmuxp_echo("%s is empty or parsed no workspace data" % workspace_file)
@@ -458,8 +473,9 @@ def load_workspace(
         )
 
         if choice == "k":
-            builder.session.kill_session()
-            tmuxp_echo("Session killed.")
+            if builder.session is not None:
+                builder.session.kill()
+                tmuxp_echo("Session killed.")
         elif choice == "a":
             _reattach(builder)
         else:
@@ -468,29 +484,8 @@ def load_workspace(
     return _setup_plugins(builder)
 
 
-def workspace_file_completion(ctx, params, incomplete):
-    workspace_dir = pathlib.Path(get_workspace_dir())
-    choices: t.List[pathlib.Path] = []
-
-    # CWD Paths
-    choices += sorted(
-        pathlib.Path(os.path.relpath(p, pathlib.Path.cwd()))
-        for p in [pathlib.Path.cwd(), *pathlib.Path.cwd().parents]
-        if in_dir(str(p)) or len(list(p.glob(".tmuxp.*")))
-    )
-    # CWD look one directory up
-    choices += [
-        pathlib.Path(f"./{os.path.relpath(p, pathlib.Path.cwd())}")
-        for p in pathlib.Path.cwd().glob("*/.tmuxp.*")
-    ]
-
-    # Project workspace
-    choices += sorted((workspace_dir / c).stem for c in in_dir(str(workspace_dir)))
-
-    return sorted(str(c) for c in choices if str(c).startswith(incomplete))
-
-
 def create_load_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``load`` subcommand."""
     workspace_files = parser.add_argument(
         "workspace_files",
         nargs="+",
@@ -642,7 +637,8 @@ def command_load(
 
     for idx, workspace_file in enumerate(args.workspace_files):
         workspace_file = find_workspace_file(
-            workspace_file, workspace_dir=get_workspace_dir()
+            workspace_file,
+            workspace_dir=get_workspace_dir(),
         )
 
         detached = original_detached_option
