@@ -1,3 +1,4 @@
+"""CLI for ``tmuxp ls`` subcommand."""
 import argparse
 import os
 import typing as t
@@ -9,12 +10,14 @@ from tmuxp.workspace.finders import get_workspace_dir
 def create_ls_subparser(
     parser: argparse.ArgumentParser,
 ) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``ls`` subcommand."""
     return parser
 
 
 def command_ls(
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
+    """Entrypoint for ``tmuxp ls`` subcommand."""
     tmuxp_dir = get_workspace_dir()
     if os.path.exists(tmuxp_dir) and os.path.isdir(tmuxp_dir):
         for f in sorted(os.listdir(tmuxp_dir)):
