@@ -1,12 +1,11 @@
-"""Internal :term:`type annotations <annotation>`
+"""Internal :term:`type annotations <annotation>`.
 
 Notes
 -----
-
 :class:`StrPath` and :class:`StrOrBytesPath` is based on `typeshed's`_.
 
 .. _typeshed's: https://github.com/python/typeshed/blob/9687d5/stdlib/_typeshed/__init__.pyi#L98
-"""  # NOQA E501
+"""  # E501
 from os import PathLike
 from typing import Union
 
