@@ -1,9 +1,4 @@
-"""Create a tmux workspace from a workspace :py:obj:`dict`.
-
-tmuxp.workspace.builder
-~~~~~~~~~~~~~~~~~~~~~~~
-
-"""
+"""Create a tmux workspace from a workspace :py:obj:`dict`."""
 import logging
 import time
 import typing as t
@@ -33,7 +28,6 @@ class WorkspaceBuilder:
 
     Examples
     --------
-
     >>> import yaml
 
     >>> session_config = yaml.load('''
@@ -98,7 +92,7 @@ class WorkspaceBuilder:
 
     1. Load JSON / YAML file via via :class:`pathlib.Path`::
 
-           from tmuxp import config_reader
+           from tmuxp._internal import config_reader
            session_config = config_reader.ConfigReader._load(raw_yaml)
 
        The reader automatically detects the file type from :attr:`pathlib.suffix`.
@@ -106,7 +100,7 @@ class WorkspaceBuilder:
        We can also parse raw file::
 
            import pathlib
-           from tmuxp import config_reader
+           from tmuxp._internal import config_reader
 
            session_config = config_reader.ConfigReader._from_file(
                pathlib.Path('path/to/config.yaml')
@@ -141,7 +135,7 @@ class WorkspaceBuilder:
         self,
         session_config: t.Dict[str, t.Any],
         server: Server,
-        plugins: t.List[t.Any] = [],
+        plugins: t.Optional[t.List[t.Any]] = None,
     ) -> None:
         """Initialize workspace loading.
 
@@ -161,9 +155,10 @@ class WorkspaceBuilder:
         TODO: Initialize :class:`libtmux.Session` from here, in
         ``self.session``.
         """
-
+        if plugins is None:
+            plugins = []
         if not session_config:
-            raise exc.EmptyWorkspaceException("Session configuration is empty.")
+            raise exc.EmptyWorkspaceException()
 
         # validation.validate_schema(session_config)
 
@@ -174,11 +169,11 @@ class WorkspaceBuilder:
         self.plugins = plugins
 
         if self.server is not None and self.session_exists(
-            session_name=self.session_config["session_name"]
+            session_name=self.session_config["session_name"],
         ):
             try:
                 session = self.server.sessions.get(
-                    session_name=self.session_config["session_name"]
+                    session_name=self.session_config["session_name"],
                 )
                 assert session is not None
                 self._session = session
@@ -186,15 +181,14 @@ class WorkspaceBuilder:
                 pass
 
     @property
-    def session(self):
+    def session(self) -> Session:
+        """Return tmux session using in workspace builder session."""
         if self._session is None:
-            raise ObjectDoesNotExist(
-                "No session object exists for WorkspaceBuilder. "
-                "Tip: Add session_name in constructor or run WorkspaceBuilder.build()"
-            )
+            raise exc.SessionMissingWorkspaceException()
         return self._session
 
     def session_exists(self, session_name: str) -> bool:
+        """Return true if tmux session already exists."""
         assert session_name is not None
         assert isinstance(session_name, str)
         assert self.server is not None
@@ -223,12 +217,11 @@ class WorkspaceBuilder:
         append : bool
             append windows in current active session
         """
-
         if not session:
             if not self.server:
                 raise exc.TmuxpException(
                     "WorkspaceBuilder.build requires server to be passed "
-                    + "on initialization, or pass in session object to here."
+                    + "on initialization, or pass in session object to here.",
                 )
             else:
                 new_session_kwargs = {}
@@ -256,7 +249,7 @@ class WorkspaceBuilder:
         assert session.server is not None
 
         self.server: "Server" = session.server
-        self.server.sessions
+        assert self.server.sessions is not None
         assert self.server.has_session(session.name)
         assert session.id
 
@@ -276,9 +269,9 @@ class WorkspaceBuilder:
                 if "start_directory" in self.session_config:
                     cwd = self.session_config["start_directory"]
                 run_before_script(self.session_config["before_script"], cwd=cwd)
-            except Exception as e:
-                self.session.kill_session()
-                raise e
+            except Exception:
+                self.session.kill()
+                raise
 
         if "options" in self.session_config:
             for option, value in self.session_config["options"].items():
@@ -306,10 +299,10 @@ class WorkspaceBuilder:
                 if "layout" in window_config:
                     window.select_layout(window_config["layout"])
 
-                if "focus" in pane_config and pane_config["focus"]:
+                if pane_config.get("focus"):
                     focus_pane = pane
 
-            if "focus" in window_config and window_config["focus"]:
+            if window_config.get("focus"):
                 focus = window
 
             self.config_after_window(window, window_config)
@@ -318,13 +311,15 @@ class WorkspaceBuilder:
                 plugin.after_window_finished(window)
 
             if focus_pane:
-                focus_pane.select_pane()
+                focus_pane.select()
 
         if focus:
-            focus.select_window()
+            focus.select()
 
     def iter_create_windows(
-        self, session: Session, append: bool = False
+        self,
+        session: Session,
+        append: bool = False,
     ) -> t.Iterator[t.Any]:
         """Return :class:`libtmux.Window` iterating through session config dict.
 
@@ -347,15 +342,15 @@ class WorkspaceBuilder:
             that was used to create the window.
         """
         for window_iterator, window_config in enumerate(
-            self.session_config["windows"], start=1
+            self.session_config["windows"],
+            start=1,
         ):
-            if "window_name" not in window_config:
-                window_name = None
-            else:
-                window_name = window_config["window_name"]
+            window_name = window_config.get("window_name", None)
 
             is_first_window_pass = self.first_window_pass(
-                window_iterator, session, append
+                window_iterator,
+                session,
+                append,
             )
 
             w1 = None
@@ -363,20 +358,14 @@ class WorkspaceBuilder:
                 w1 = session.attached_window
                 w1.move_window("99")
 
-            if "start_directory" in window_config:
-                start_directory = window_config["start_directory"]
-            else:
-                start_directory = None
+            start_directory = window_config.get("start_directory", None)
 
             # If the first pane specifies a start_directory, use that instead.
             panes = window_config["panes"]
             if panes and "start_directory" in panes[0]:
                 start_directory = panes[0]["start_directory"]
 
-            if "window_shell" in window_config:
-                window_shell = window_config["window_shell"]
-            else:
-                window_shell = None
+            window_shell = window_config.get("window_shell", None)
 
             # If the first pane specifies a shell, use that instead.
             try:
@@ -399,7 +388,7 @@ class WorkspaceBuilder:
                     target = "windows"
                 logger.warning(
                     f"Cannot set environment for new {target}. "
-                    "You need tmux 3.0 or newer for this."
+                    "You need tmux 3.0 or newer for this.",
                 )
                 environment = None
 
@@ -414,21 +403,24 @@ class WorkspaceBuilder:
             assert isinstance(window, Window)
 
             if is_first_window_pass:  # if first window, use window 1
-                session.attached_window.kill_window()
+                session.attached_window.kill()
 
             if "options" in window_config and isinstance(
-                window_config["options"], dict
+                window_config["options"],
+                dict,
             ):
                 for key, val in window_config["options"].items():
                     window.set_window_option(key, val)
 
-            if "focus" in window_config and window_config["focus"]:
-                window.select_window()
+            if window_config.get("focus"):
+                window.select()
 
             yield window, window_config
 
     def iter_create_panes(
-        self, window: Window, window_config: t.Dict[str, t.Any]
+        self,
+        window: Window,
+        window_config: t.Dict[str, t.Any],
     ) -> t.Iterator[t.Any]:
         """Return :class:`libtmux.Pane` iterating through window config dict.
 
@@ -456,13 +448,17 @@ class WorkspaceBuilder:
         pane = None
 
         for pane_index, pane_config in enumerate(
-            window_config["panes"], start=pane_base_index
+            window_config["panes"],
+            start=pane_base_index,
         ):
             if pane_index == int(pane_base_index):
                 pane = window.attached_pane
             else:
 
-                def get_pane_start_directory():
+                def get_pane_start_directory(
+                    pane_config: t.Dict[str, str],
+                    window_config: t.Dict[str, str],
+                ) -> t.Optional[str]:
                     if "start_directory" in pane_config:
                         return pane_config["start_directory"]
                     elif "start_directory" in window_config:
@@ -470,7 +466,10 @@ class WorkspaceBuilder:
                     else:
                         return None
 
-                def get_pane_shell():
+                def get_pane_shell(
+                    pane_config: t.Dict[str, str],
+                    window_config: t.Dict[str, str],
+                ) -> t.Optional[str]:
                     if "shell" in pane_config:
                         return pane_config["shell"]
                     elif "window_shell" in window_config:
@@ -479,7 +478,8 @@ class WorkspaceBuilder:
                         return None
 
                 environment = pane_config.get(
-                    "environment", window_config.get("environment")
+                    "environment",
+                    window_config.get("environment"),
                 )
                 if environment and has_lt_version("3.0"):
                     # Just issue a warning when the environment comes from the pane
@@ -488,7 +488,7 @@ class WorkspaceBuilder:
                     if pane_config.get("environment"):
                         logger.warning(
                             "Cannot set environment for new panes. "
-                            "You need tmux 3.0 or newer for this."
+                            "You need tmux 3.0 or newer for this.",
                         )
                     environment = None
 
@@ -496,8 +496,14 @@ class WorkspaceBuilder:
 
                 pane = window.split_window(
                     attach=True,
-                    start_directory=get_pane_start_directory(),
-                    shell=get_pane_shell(),
+                    start_directory=get_pane_start_directory(
+                        pane_config=pane_config,
+                        window_config=window_config,
+                    ),
+                    shell=get_pane_shell(
+                        pane_config=pane_config,
+                        window_config=window_config,
+                    ),
                     target=pane.id,
                     environment=environment,
                 )
@@ -530,14 +536,16 @@ class WorkspaceBuilder:
                 if sleep_after is not None:
                     time.sleep(sleep_after)
 
-            if "focus" in pane_config and pane_config["focus"]:
+            if pane_config.get("focus"):
                 assert pane.pane_id is not None
                 window.select_pane(pane.pane_id)
 
             yield pane, pane_config
 
     def config_after_window(
-        self, window: Window, window_config: t.Dict[str, t.Any]
+        self,
+        window: Window,
+        window_config: t.Dict[str, t.Any],
     ) -> None:
         """Actions to apply to window after window and pane finished.
 
@@ -553,18 +561,20 @@ class WorkspaceBuilder:
             config section for window
         """
         if "options_after" in window_config and isinstance(
-            window_config["options_after"], dict
+            window_config["options_after"],
+            dict,
         ):
             for key, val in window_config["options_after"].items():
                 window.set_window_option(key, val)
 
     def find_current_attached_session(self) -> Session:
+        """Return current attached session."""
         assert self.server is not None
 
         current_active_pane = get_current_pane(self.server)
 
         if current_active_pane is None:
-            raise exc.TmuxpException("No session active.")
+            raise exc.ActiveSessionMissingWorkspaceException()
 
         return next(
             (
@@ -575,4 +585,5 @@ class WorkspaceBuilder:
         )
 
     def first_window_pass(self, i: int, session: Session, append: bool) -> bool:
+        """Return True first window, used when iterating session windows."""
         return len(session.windows) == 1 and i == 1 and not append
