@@ -1,3 +1,4 @@
+"""CLI tests for tmuxp debuginfo."""
 import pathlib
 
 import pytest
@@ -8,8 +9,9 @@ from tmuxp import cli
 def test_debug_info_cli(
     monkeypatch: pytest.MonkeyPatch,
     tmp_path: pathlib.Path,
-    capsys: pytest.CaptureFixture,
+    capsys: pytest.CaptureFixture[str],
 ) -> None:
+    """Basic CLI test for tmuxp debug-info."""
     monkeypatch.setenv("SHELL", "/bin/bash")
 
     cli.cli(["debug-info"])
