@@ -1,4 +1,5 @@
-import os
+"""CLI tests for tmuxp ls command."""
+import contextlib
 import pathlib
 
 import pytest
@@ -9,8 +10,9 @@ from tmuxp import cli
 def test_ls_cli(
     monkeypatch: pytest.MonkeyPatch,
     tmp_path: pathlib.Path,
-    capsys: pytest.CaptureFixture,
+    capsys: pytest.CaptureFixture[str],
 ) -> None:
+    """CLI test for tmuxp ls."""
     monkeypatch.setenv("HOME", str(tmp_path))
     monkeypatch.setenv("XDG_CONFIG_HOME", str(tmp_path / ".config"))
 
@@ -27,7 +29,7 @@ def test_ls_cli(
     # - directories should be ignored
     # - extensions not covered in VALID_WORKSPACE_DIR_FILE_EXTENSIONS
     ignored_filenames = [".git/", ".gitignore/", "session_4.txt"]
-    stems = [os.path.splitext(f)[0] for f in filenames if f not in ignored_filenames]
+    stems = [pathlib.Path(f).stem for f in filenames if f not in ignored_filenames]
 
     for filename in filenames:
         location = tmp_path / f".tmuxp/{filename}"
@@ -36,10 +38,9 @@ def test_ls_cli(
         else:
             location.touch()
 
-    try:
+    with contextlib.suppress(SystemExit):
         cli.cli(["ls"])
-    except SystemExit:
-        pass
+
     cli_output = capsys.readouterr().out
 
     assert cli_output == "\n".join(stems) + "\n"
