@@ -1,3 +1,4 @@
+"""Teamocil data fixtures for import_teamocil tests, 1st test."""
 from .. import utils as test_utils
 
 teamocil_yaml = test_utils.read_workspace_file("import_teamocil/test1.yaml")
@@ -8,8 +9,8 @@ teamocil_conf = {
             "root": "~/Code/sample/www",
             "layout": "even-horizontal",
             "panes": [{"cmd": ["pwd", "ls -la"]}, {"cmd": "rails server --port 3000"}],
-        }
-    ]
+        },
+    ],
 }
 
 expected = {
@@ -23,6 +24,6 @@ expected = {
                 {"shell_command": ["pwd", "ls -la"]},
                 {"shell_command": "rails server --port 3000"},
             ],
-        }
+        },
     ],
 }
