@@ -1,3 +1,4 @@
+"""Teamocil data fixtures for import_teamocil tests, 2nd test."""
 from .. import utils as test_utils
 
 teamocil_yaml = test_utils.read_workspace_file("import_teamocil/test2.yaml")
@@ -8,8 +9,8 @@ teamocil_dict = {
             "root": "~/Code/sample/www",
             "layout": "tiled",
             "panes": [{"cmd": "pwd"}, {"cmd": "pwd"}, {"cmd": "pwd"}, {"cmd": "pwd"}],
-        }
-    ]
+        },
+    ],
 }
 
 expected = {
@@ -25,6 +26,6 @@ expected = {
                 {"shell_command": "pwd"},
                 {"shell_command": "pwd"},
             ],
-        }
+        },
     ],
 }
