@@ -1,3 +1,4 @@
+"""Teamocil data fixtures for import_teamocil tests, 3rd test."""
 from .. import utils as test_utils
 
 teamocil_yaml = test_utils.read_workspace_file("import_teamocil/test3.yaml")
@@ -17,8 +18,8 @@ teamocil_dict = {
                 {"cmd": "bundle exec rails server --port 40", "focus": True},
                 {"cmd": ["sudo service memcached start", "sudo service mongodb start"]},
             ],
-        }
-    ]
+        },
+    ],
 }
 
 expected = {
@@ -37,9 +38,9 @@ expected = {
                     "shell_command": [
                         "sudo service memcached start",
                         "sudo service mongodb start",
-                    ]
+                    ],
                 },
             ],
-        }
+        },
     ],
 }
