@@ -1,3 +1,4 @@
+"""Tmuxinator data fixtures for import_tmuxinator tests, 1st dataset."""
 from .. import utils as test_utils
 
 tmuxinator_yaml = test_utils.read_workspace_file("import_tmuxinator/test1.yaml")
@@ -6,7 +7,7 @@ tmuxinator_dict = {
         {"editor": {"layout": "main-vertical", "panes": ["vim", "guard"]}},
         {"server": "bundle exec rails s"},
         {"logs": "tail -f logs/development.log"},
-    ]
+    ],
 }
 
 expected = {
