@@ -1,9 +1,17 @@
+"""Tmuxp test plugin with version constraints guaranteed to pass."""
+import typing as t
+
 from .test_plugin_helpers import MyTestTmuxpPlugin
 
+if t.TYPE_CHECKING:
+    from ._types import PluginTestConfigSchema
+
 
 class AllVersionPassPlugin(MyTestTmuxpPlugin):
+    """Tmuxp plugin with config constraints guaranteed to validate."""
+
     def __init__(self) -> None:
-        config = {
+        config: "PluginTestConfigSchema" = {
             "plugin_name": "tmuxp-plugin-my-tmuxp-plugin",
             "tmux_min_version": "1.8",
             "tmux_max_version": "100.0",
@@ -17,4 +25,4 @@ class AllVersionPassPlugin(MyTestTmuxpPlugin):
             "tmux_version": "3.0",
             "tmuxp_version": "1.7.0",
         }
-        MyTestTmuxpPlugin.__init__(self, config)
+        MyTestTmuxpPlugin.__init__(self, **config)
