@@ -1,16 +1,32 @@
-from typing import Iterable, Mapping, Union
+"""Tmuxp test plugin for asserting version constraints."""
+import typing as t
 
 from tmuxp.plugin import TmuxpPlugin
 
+if t.TYPE_CHECKING:
+    from typing_extensions import Unpack
+
+    from tmuxp._internal.types import PluginConfigSchema
+
+    from ._types import PluginTestConfigSchema
+
 
 class MyTestTmuxpPlugin(TmuxpPlugin):
-    def __init__(self, config: Mapping[str, Union[str, Iterable[str]]]) -> None:
+    """Base class for testing tmuxp plugins with version constraints."""
+
+    def __init__(self, **config: "Unpack[PluginTestConfigSchema]") -> None:
         assert isinstance(config, dict)
         tmux_version = config.pop("tmux_version", None)
         libtmux_version = config.pop("libtmux_version", None)
         tmuxp_version = config.pop("tmuxp_version", None)
 
-        TmuxpPlugin.__init__(self, **config)
+        t.cast("PluginConfigSchema", config)
+
+        assert "tmux_version" not in config
+
+        # tests/fixtures/pluginsystem/partials/test_plugin_helpers.py:24: error: Extra
+        # argument "tmux_version" from **args for "__init__" of "TmuxpPlugin"  [misc]
+        super().__init__(**config)  # type:ignore
 
         # WARNING! This should not be done in anything but a test
         if tmux_version:
