@@ -1,4 +1,5 @@
-from . import (  # noqa
+"""Workspace data fixtures for tmuxp tests."""
+from . import (
     expand1,
     expand2,
     expand_blank,
