@@ -1,3 +1,4 @@
+"""Example workspace fixture for tmuxp WorkspaceBuilder."""
 sample_workspace_dict = {
     "session_name": "sample workspace",
     "start_directory": "~",
@@ -8,7 +9,7 @@ sample_workspace_dict = {
                 {"start_directory": "~", "shell_command": ["vim"]},
                 {"shell_command": ['cowsay "hey"']},
             ],
-            "layout": "main-verticle",
+            "layout": "main-vertical",
         },
         {
             "window_name": "logging",
@@ -16,7 +17,7 @@ sample_workspace_dict = {
                 {
                     "shell_command": ["tail -F /var/log/syslog"],
                     "start_directory": "/var/log",
-                }
+                },
             ],
         },
         {"options": {"automatic_rename": True}, "panes": [{"shell_command": ["htop"]}]},
