@@ -1,3 +1,4 @@
+"""Test data for tmuxp workspace fixture to demo object tree inheritance."""
 before = {  # shell_command_before is string in some areas
     "session_name": "sample workspace",
     "start_directory": "/var",
@@ -9,7 +10,7 @@ before = {  # shell_command_before is string in some areas
                 {"shell_command": [{"cmd": "vim"}]},
                 {"shell_command": [{"cmd": 'cowsay "hey"'}]},
             ],
-            "layout": "main-verticle",
+            "layout": "main-vertical",
         },
         {
             "window_name": "logging",
@@ -33,7 +34,7 @@ expected = {  # shell_command_before is string in some areas
                 {"shell_command": [{"cmd": "vim"}]},
                 {"shell_command": [{"cmd": 'cowsay "hey"'}]},
             ],
-            "layout": "main-verticle",
+            "layout": "main-vertical",
         },
         {
             "start_directory": "~",
