@@ -1,3 +1,4 @@
+"""Pytest configuration for tmuxp workspace tests."""
 import types
 
 import pytest
@@ -7,7 +8,7 @@ from ..fixtures.structures import WorkspaceTestData
 
 @pytest.fixture
 def config_fixture() -> WorkspaceTestData:
-    """Deferred import of tmuxp.tests.fixtures.*
+    """Deferred import of tmuxp.tests.fixtures.*.
 
     pytest setup (conftest.py) patches os.environ["HOME"], delay execution of
     os.path.expanduser until here.
@@ -19,5 +20,5 @@ def config_fixture() -> WorkspaceTestData:
             k: v
             for k, v in test_workspace_data.__dict__.items()
             if isinstance(v, types.ModuleType)
-        }
+        },
     )
