@@ -3,7 +3,7 @@ import typing as t
 
 import pytest
 
-from tmuxp.config_reader import ConfigReader
+from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.workspace import importers, validation
 
 from ..fixtures import import_tmuxinator as fixtures
@@ -34,7 +34,8 @@ def test_config_to_dict(
     tmuxinator_dict: t.Dict[str, t.Any],
     tmuxp_dict: t.Dict[str, t.Any],
 ) -> None:
-    yaml_to_dict = ConfigReader._load(format="yaml", content=tmuxinator_yaml)
+    """Test exporting tmuxinator configuration to dictionary."""
+    yaml_to_dict = ConfigReader._load(fmt="yaml", content=tmuxinator_yaml)
     assert yaml_to_dict == tmuxinator_dict
 
     assert importers.import_tmuxinator(tmuxinator_dict) == tmuxp_dict
